==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/WorkloadNetworkSegmentSubnetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Subnet configuration for segment
 * @property dhcpRanges DHCP Range assigned for subnet.
 * @property gatewayAddress Gateway address.
 */
public data class WorkloadNetworkSegmentSubnetArgs(
    public val dhcpRanges: Output<List<String>>? = null,
    public val gatewayAddress: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs =
        com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs.builder()
            .dhcpRanges(dhcpRanges?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gatewayAddress(gatewayAddress?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkloadNetworkSegmentSubnetArgs].
 */
@PulumiTagMarker
public class WorkloadNetworkSegmentSubnetArgsBuilder internal constructor() {
    private var dhcpRanges: Output<List<String>>? = null

    private var gatewayAddress: Output<String>? = null

    /**
     * @param value DHCP Range assigned for subnet.
     */
    @JvmName("sdwsxuxgvmrdfvxf")
    public suspend fun dhcpRanges(`value`: Output<List<String>>) {
        this.dhcpRanges = value
    }

    @JvmName("btkehosuyqrromct")
    public suspend fun dhcpRanges(vararg values: Output<String>) {
        this.dhcpRanges = Output.all(values.asList())
    }

    /**
     * @param values DHCP Range assigned for subnet.
     */
    @JvmName("etbwuhngxiwfkuep")
    public suspend fun dhcpRanges(values: List<Output<String>>) {
        this.dhcpRanges = Output.all(values)
    }

    /**
     * @param value Gateway address.
     */
    @JvmName("kevanbudcrbtwwov")
    public suspend fun gatewayAddress(`value`: Output<String>) {
        this.gatewayAddress = value
    }

    /**
     * @param value DHCP Range assigned for subnet.
     */
    @JvmName("qaotrsienjbuyetq")
    public suspend fun dhcpRanges(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dhcpRanges = mapped
    }

    /**
     * @param values DHCP Range assigned for subnet.
     */
    @JvmName("vltmhdekfiuigrsa")
    public suspend fun dhcpRanges(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dhcpRanges = mapped
    }

    /**
     * @param value Gateway address.
     */
    @JvmName("kkbqxeuisiexxbls")
    public suspend fun gatewayAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gatewayAddress = mapped
    }

    internal fun build(): WorkloadNetworkSegmentSubnetArgs = WorkloadNetworkSegmentSubnetArgs(
        dhcpRanges = dhcpRanges,
        gatewayAddress = gatewayAddress,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/WorkloadNetworkSegmentSubnetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Subnet configuration for segment
 * @property dhcpRanges DHCP Range assigned for subnet.
 * @property gatewayAddress Gateway address.
 */
public data class WorkloadNetworkSegmentSubnetArgs(
    public val dhcpRanges: Output<List<String>>? = null,
    public val gatewayAddress: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs =
        com.pulumi.azurenative.avs.inputs.WorkloadNetworkSegmentSubnetArgs.builder()
            .dhcpRanges(dhcpRanges?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gatewayAddress(gatewayAddress?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkloadNetworkSegmentSubnetArgs].
 */
@PulumiTagMarker
public class WorkloadNetworkSegmentSubnetArgsBuilder internal constructor() {
    private var dhcpRanges: Output<List<String>>? = null

    private var gatewayAddress: Output<String>? = null

    /**
     * @param value DHCP Range assigned for subnet.
     */
    @JvmName("arnxuunanveiljfs")
    public suspend fun dhcpRanges(`value`: Output<List<String>>) {
        this.dhcpRanges = value
    }

    @JvmName("guwpiehjxoxkofuv")
    public suspend fun dhcpRanges(vararg values: Output<String>) {
        this.dhcpRanges = Output.all(values.asList())
    }

    /**
     * @param values DHCP Range assigned for subnet.
     */
    @JvmName("ukgjmpessdtbforn")
    public suspend fun dhcpRanges(values: List<Output<String>>) {
        this.dhcpRanges = Output.all(values)
    }

    /**
     * @param value Gateway address.
     */
    @JvmName("mmdljgyktvyopngh")
    public suspend fun gatewayAddress(`value`: Output<String>) {
        this.gatewayAddress = value
    }

    /**
     * @param value DHCP Range assigned for subnet.
     */
    @JvmName("bgdohgmslajbvqwg")
    public suspend fun dhcpRanges(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dhcpRanges = mapped
    }

    /**
     * @param values DHCP Range assigned for subnet.
     */
    @JvmName("hgnxfinhsfaqxmyb")
    public suspend fun dhcpRanges(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dhcpRanges = mapped
    }

    /**
     * @param value Gateway address.
     */
    @JvmName("bboqkdohmdkpleby")
    public suspend fun gatewayAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gatewayAddress = mapped
    }

    internal fun build(): WorkloadNetworkSegmentSubnetArgs = WorkloadNetworkSegmentSubnetArgs(
        dhcpRanges = dhcpRanges,
        gatewayAddress = gatewayAddress,
    )
}
